@@ -23,7 +23,7 @@
 #'                                  name = "joined_cohorts",
 #'                                  indexTable = "cohort_1",
 #'                                  markerTable = "cohort_2")
-#' temporal_symmetry <- summariseTemporalSymmetry(cohort = cdm$joined_cohorts)
+#' temporal_symmetry <- summariseTemporalSymmetry(cohort = cdm$joined_cohorts, minCellCount = 0)
 #' CDMConnector::cdmDisconnect(cdm)
 #' }
 #'
@@ -31,13 +31,19 @@ summariseTemporalSymmetry <- function(cohort,
                                       cohortId = NULL,
                                       timescale = "month",
                                       minCellCount = 5) {
-
   # checks
-  checkInputSummariseTemporalSymmetry(cohort = cohort,
-                                      cohortId = cohortId,
-                                      timescale = timescale,
-                                      minCellCount = minCellCount)
+  cdm <- omopgenerics::cdmReference(cohort)
+  cdm <- omopgenerics::validateCdmArgument(cdm = cdm)
+  cohortId <- omopgenerics::validateCohortIdArgument({{cohortId}}, cohort)
+  omopgenerics::assertChoice(timescale,
+                             choices = c("day", "week","month", "year"),
+                             length = 1)
+  omopgenerics::assertNumeric(minCellCount,
+                              min = 0,
+                              max = 99999999,
+                              length = 1)
 
+  # pulling out data
   index_names <- attr(cohort, "cohort_set") |>
     dplyr::select("cohort_definition_id", "index_name", "index_id", "marker_id")
   marker_names <- attr(cohort, "cohort_set") |>
@@ -45,9 +51,10 @@ summariseTemporalSymmetry <- function(cohort,
   cohort_settings <- omopgenerics::settings(cohort)|>
     dplyr::mutate(timescale = .env$timescale) |>
     dplyr::select(-c("index_id", "marker_id", "index_name", "marker_name"))
-  settings <- c("days_prior_observation", "washout_window", "index_marker_gap",
-                "combination_window", "timescale")
+  settings <- c("cohort_date_range", "days_prior_observation", "washout_window", "index_marker_gap",
+                "combination_window", "moving_average_restriction", "timescale")
 
+  # computing the output
   output <- cohort %>%
     dplyr::mutate(time = as.numeric(!!CDMConnector::datediff(
       "index_date", "marker_date", interval = timescale))) |>
@@ -89,7 +96,7 @@ summariseTemporalSymmetry <- function(cohort,
     dplyr::mutate(variable_name  = "temporal_symmetry",
                   variable_level = as.character(.data$variable_level),
                   estimate_value = as.character(.data$estimate_value),
-                  strata_name = "overall", #to change
+                  strata_name = "overall",
                   strata_level = "overall",
                   additional_name = "overall",
                   additional_level = "overall",
@@ -103,10 +110,12 @@ summariseTemporalSymmetry <- function(cohort,
   setting <- output_sum |>
     dplyr::distinct(dplyr::across(dplyr::all_of(c(settings, "cdm_name")))) |>
     dplyr::mutate(result_id = as.integer(dplyr::row_number()),
-                  result_type = "sequence_ratios",
+                  result_type = "temporal_symmetry",
                   package_name = "CohortSymmetry",
-                  package_version = as.character(utils::packageVersion("CohortSymmetry")))
+                  package_version = as.character(utils::packageVersion("CohortSymmetry")),
+                  timescale = .env$timescale)
 
+  # new summarise result
   output_sum <- output_sum |>
     dplyr::left_join(setting, by = c("cdm_name", "days_prior_observation", "washout_window",
                                      "index_marker_gap", "combination_window", "timescale")) |>
