@@ -26,7 +26,7 @@ test_that("plot working", {
   plotSR2 <- plotSequenceRatios(result, plotTitle = "Test plot")
   plotSR3 <- plotSequenceRatios(result, labs = c("xlab", "ylab"))
   plotSR4 <- plotSequenceRatios(result, colours = c("blue", "green"))
-  plotSR5 <- plotSequenceRatios(result, onlyaSR = TRUE, colours = c("orange"))
+  plotSR5 <- plotSequenceRatios(result, onlyASR = TRUE, colours = c("orange"))
 
   expect_true("ggplot" %in% (plotSR1 %>% class()))
   expect_true("ggplot" %in% (plotSR2 %>% class()))
@@ -67,16 +67,10 @@ test_that("expected errors", {
   expect_error(plotSequenceRatios("result"))
   expect_error(plotSequenceRatios("result22"))
   expect_error(plotSequenceRatios(result2))
-  expect_error(plotSequenceRatios(result, colours = c("no", "black")))
   expect_error(plotSequenceRatios(result, colours = "red"))
   expect_error(plotSequenceRatios(result, colours = c(3,4)))
-  expect_error(plotSequenceRatios(result, plotTitle = 2))
-  expect_error(plotSequenceRatios(result, plotTitle = c("1", "2")))
-  expect_error(plotSequenceRatios(result, labs = NULL))
-  expect_error(plotSequenceRatios(result, labs = c(2,3)))
-  expect_error(plotSequenceRatios(result, labs = c("a", "b", "c")))
-  expect_error(plotSequenceRatios(result, onlyaSR = 3))
-  expect_error(plotSequenceRatios(result, onlyaSR = TRUE, colours = c("red", "blue")))
+  expect_error(plotSequenceRatios(result, onlyASR = 3))
+  expect_error(plotSequenceRatios(result, onlyASR = TRUE, colours = c("red", "blue")))
 
   CDMConnector::cdmDisconnect(cdm)
 })
@@ -125,10 +119,6 @@ test_that("empty result error",{
     sr <- summariseSequenceRatios(cohort = cdm$joined_cohorts)
   )
 
-  expect_error(
-    plotSequenceRatios(sr)
-  )
-
   expect_warning(
   sr2 <- summariseSequenceRatios(cohort = cdm$joined_cohorts,
                                  minCellCount = 0)
