@@ -118,7 +118,7 @@ test_that("summariseSequenceRatios - testing ratios and CIs, Example 1", {
 
   expect_true(all(res$days_prior_observation==0))
   expect_true(all(res$washout_window==0))
-  expect_true(all(res$combination_window == "(0,365)"))
+  expect_true(all(res$combination_window == "0, 365"))
   expect_true(all(res$index_marker_gap=="Inf"))
   expect_true(all(res$confidence_interval==95))
   expect_true(all(as.integer(res$first_pharmac_index_percentage)<=100 & 0 <= as.integer(res$first_pharmac_index_percentage)))
@@ -179,11 +179,11 @@ test_that("summariseSequenceRatios - testing ratios and CIs, Example 2", {
     dplyr::select(-"estimate_type") |>
     tidyr::pivot_wider(names_from = c("variable_level", "variable_name", "estimate_name"),
                        values_from = "estimate_value") |>
-    dplyr::left_join(res |> omopgenerics::settings())
+    dplyr::left_join(res |> omopgenerics::settings(), by = c("result_id", "cdm_name"))
 
   expect_true(all(res$days_prior_observation==0))
   expect_true(all(res$washout_window==0))
-  expect_true(all(res$combination_window == "(0,365)"))
+  expect_true(all(res$combination_window == "0, 365"))
   expect_true(all(res$index_marker_gap=="Inf"))
   expect_true(all(res$confidence_interval==95))
   expect_true((res$index_cohort_name=="cohort_1"))
@@ -953,12 +953,61 @@ test_that("min cell count",{
       nrow()|>
       as.numeric())
 
-  expect_true(all(
-    (result2 %>%
-      dplyr::select(estimate_value) %>%
-      dplyr::mutate(estimate_value = as.numeric(estimate_value)) %>%
-      dplyr::pull(estimate_value))%in% c(NA, 0)
-  ))
-
   CDMConnector::cdm_disconnect(cdm = cdm)
 })
+
+test_that("Inf CI", {
+  skip_on_cran()
+  indexCohort <- dplyr::tibble(
+    cohort_definition_id = c(1, 1, 1, 1),
+    subject_id = c(1, 2, 3, 4),
+    cohort_start_date = as.Date(
+      c(
+        "2020-04-01", "2021-06-01", "2022-05-22", "2010-01-01"
+      )
+    ),
+    cohort_end_date = as.Date(
+      c(
+        "2020-04-01", "2021-06-01", "2022-05-22", "2010-01-01"
+      )
+    )
+  )|>
+    dplyr::mutate(cohort_definition_id = as.integer(.data$cohort_definition_id),
+                  subject_id = as.integer(.data$subject_id))
+
+  markerCohort <- dplyr::tibble(
+    cohort_definition_id = c(1, 1, 1, 1),
+    subject_id = c(1, 2, 3, 4),
+    cohort_start_date = as.Date(
+      c(
+        "2020-04-02", "2021-06-02", "2022-05-23", "2010-01-02"
+      )
+    ),
+    cohort_end_date = as.Date(
+      c(
+        "2020-04-02", "2021-06-02", "2022-05-23", "2010-01-02"
+      )
+    )
+  )|>
+    dplyr::mutate(cohort_definition_id = as.integer(.data$cohort_definition_id),
+                  subject_id = as.integer(.data$subject_id))
+
+  cdm <- mockCohortSymmetry(indexCohort = indexCohort,
+                            markerCohort = markerCohort)
+
+  cdm <- generateSequenceCohortSet(cdm = cdm,
+                                   name = "joined_cohorts",
+                                   indexTable = "cohort_1",
+                                   markerTable = "cohort_2")
+
+  expect_warning(
+    res <- summariseSequenceRatios(cohort = cdm$joined_cohorts)
+  )
+
+  expect_true(
+    all(res |>
+          dplyr::filter(estimate_name %in% c("lower_CI", "upper_CI")) |>
+          dplyr::pull("estimate_value") == "Inf"
+        )
+  )
+})
